Installing — huey 0.4.0 documentation

### Navigation

- index
- next |
- previous |
- huey 0.4.0 documentation »

# Installing

huey can be installed very easily using pip.

    pip install huey

huey has no dependencies outside the standard library, but currently the only fully-implemented queue backend it ships with requires redis. To use the redis backend, you will need to install the python client.

    pip install redis

## Using git

If you want to run the very latest, feel free to pull down the repo from github and install by hand.

    git clone https://github.com/coleifer/huey.git
    cd huey
    python setup.py install

You can run the tests using the test-runner:

    python setup.py test

Browse the source code online at https://github.com/coleifer/huey

### Navigation

- index
- next |
- previous |
- huey 0.4.0 documentation »